@@ -78,27 +78,33 @@ pub fn get_files<'patterns>(folder_path: String, includes: &'patterns [&str], ex
 }
 
 /// A file embedded into the binary
+#[derive(Clone)]
 pub struct EmbeddedFile {
   pub data: Cow<'static, [u8]>,
   pub metadata: Metadata,
 }
 
 /// Metadata about an embedded file
+#[derive(Clone)]
 pub struct Metadata {
   hash: [u8; 32],
   last_modified: Option<u64>,
+  created: Option<u64>,
   #[cfg(feature = "mime-guess")]
   mimetype: Cow<'static, str>,
 }
 
 impl Metadata {
   #[doc(hidden)]
-  pub fn __rust_embed_new(hash: [u8; 32], last_modified: Option<u64>, #[cfg(feature = "mime-guess")] mimetype: &'static str) -> Self {
+  pub const fn __rust_embed_new(
+    hash: [u8; 32], last_modified: Option<u64>, created: Option<u64>, #[cfg(feature = "mime-guess")] mimetype: &'static str,
+  ) -> Self {
     Self {
       hash,
       last_modified,
+      created,
       #[cfg(feature = "mime-guess")]
-      mimetype: mimetype.into(),
+      mimetype: Cow::Borrowed(mimetype),
     }
   }
 
@@ -113,6 +119,12 @@ impl Metadata {
     self.last_modified
   }
 
+  /// The created data in seconds since the UNIX epoch. If the underlying
+  /// platform/file-system does not support this, None is returned.
+  pub fn created(&self) -> Option<u64> {
+    self.created
+  }
+
   /// The mime type of the file
   #[cfg(feature = "mime-guess")]
   pub fn mimetype(&self) -> &str {
@@ -129,16 +141,23 @@ pub fn read_file_from_fs(file_path: &Path) -> io::Result<EmbeddedFile> {
   let hash: [u8; 32] = hasher.finalize().into();
 
   let source_date_epoch = match std::env::var("SOURCE_DATE_EPOCH") {
-    Ok(value) => value.parse::<u64>().map_or(None, |v| Some(v)),
+    Ok(value) => value.parse::<u64>().ok(),
     Err(_) => None,
   };
 
-  let last_modified = fs::metadata(file_path)?.modified().ok().map(|last_modified| {
+  let metadata = fs::metadata(file_path)?;
+  let last_modified = metadata.modified().ok().map(|last_modified| {
     last_modified
       .duration_since(SystemTime::UNIX_EPOCH)
       .expect("Time before the UNIX epoch is unsupported")
       .as_secs()
   });
+  let created = metadata.created().ok().map(|created| {
+    created
+      .duration_since(SystemTime::UNIX_EPOCH)
+      .expect("Time before the UNIX epoch is unsupported")
+      .as_secs()
+  });
 
   #[cfg(feature = "mime-guess")]
   let mimetype = mime_guess::from_path(file_path).first_or_octet_stream().to_string();
@@ -148,6 +167,7 @@ pub fn read_file_from_fs(file_path: &Path) -> io::Result<EmbeddedFile> {
     metadata: Metadata {
       hash,
       last_modified: source_date_epoch.or(last_modified),
+      created: source_date_epoch.or(created),
       #[cfg(feature = "mime-guess")]
       mimetype: mimetype.into(),
     },
